/* IMPORTANT: s necessari estar connectat amb l'usuari ECOLLADOF amb password 12345678 abans d'executar aquest script   */
/* En aquest script es troben els procediments d'alta, baixa i modificaci de les taules de la base de dades operacional */

/***********************************************************/
/*         1- PROC ABM taula RESPONSABLE                   */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_RESPONSABLE
--Descripci :   Alta d'un nou responsable
-------------------------------------------------------------
create or replace Procedure PROC_A_RESPONSABLE(
  PNOM      In   RESPONSABLE.NOM%Type,
  PADRECA   In   RESPONSABLE.ADRECA%Type,
  PPOBLACIO In   RESPONSABLE.POBLACIO%Type,
  PRSP       Out  Nocopy Varchar2)
  
Is
param_input Varchar2(300);
codi_error  Integer;
NULL_incorrecte   exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PNOM='|| PNOM || ' PADRECA=' || PADRECA || ' PPOBLACIO=' || PPOBLACIO;
  PRSP := 'OK';
  INSERT INTO ECOLLADOF.RESPONSABLE(NOM, ADRECA, POBLACIO) VALUES (PNOM, PADRECA, PPOBLACIO);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El nom del responsable no pot ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE); 
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/
-------------------------------------------------------------
--Nom        :   PROC_B_RESPONSABLE
--Descripci :   Baixa lgica d'un responsable
-------------------------------------------------------------
create or replace Procedure  PROC_B_RESPONSABLE(
  PIDRESPONSABLE In   RESPONSABLE.IDRESPONSABLE%type,
  PRSP            Out  Nocopy Varchar2)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
seu_associada    exception;
Begin
   -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDRESPONSABLE=' || PIDRESPONSABLE;
   PRSP := 'OK';
   -- Es comprova si exsiteix el Responsable
   SELECT count(IDRESPONSABLE) INTO num_reg FROM RESPONSABLE WHERE IDRESPONSABLE = PIDRESPONSABLE;
   IF num_reg <> 0 THEN
   	-- Es comprova si t Seu associada (i la Seu no ha estat donada de baixa encara)
      SELECT count (FIDRESPONSABLE) INTO num_reg FROM SEU WHERE FIDRESPONSABLE = PIDRESPONSABLE AND DATABAIXA IS NULL;
      IF num_reg = 0 THEN
      -- Es dna de baixa si no ha estat donat de baixa abans
        UPDATE ECOLLADOF.RESPONSABLE SET DATABAIXA=SYSDATE WHERE IDRESPONSABLE = PIDRESPONSABLE AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;
      ELSE
        raise seu_associada;
	END IF;
  ELSE
      raise no_existeix;
   END IF;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Responsable ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El Responsable no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN seu_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El Responsable no es pot donar de baixa perqu t una Seu associada';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/
-------------------------------------------------------------
--Nom        :   PROC_M_RESPONSABLE
--Descripci :   Modificaci d'un responsable
-------------------------------------------------------------
create or replace Procedure  PROC_M_RESPONSABLE(
  PIDRESPONSABLE     In   RESPONSABLE.IDRESPONSABLE%Type,
  PNOM               In   RESPONSABLE.NOM%Type,
  PADRECA               In   RESPONSABLE.ADRECA%Type,
  PPOBLACIO               In   RESPONSABLE.POBLACIO%Type,
  PRSP                Out  Nocopy Varchar2)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
NULL_detected   exception;

PRAGMA EXCEPTION_INIT(NULL_detected, -1407);

Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PIDRESPONSABLE='|| PIDRESPONSABLE ||' PNOM='|| PNOM || ' PADRECA=' || PADRECA || ' PPOBLACIO=' || PPOBLACIO;
  PRSP := 'OK';
-- Es comprova si existeix el Responsable
  SELECT count(IDRESPONSABLE) INTO num_reg FROM RESPONSABLE WHERE IDRESPONSABLE = PIDRESPONSABLE;
  IF num_reg <> 0 THEN
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.RESPONSABLE SET NOM = PNOM, ADRECA = PADRECA, POBLACIO = PPOBLACIO WHERE IDRESPONSABLE = PIDRESPONSABLE  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions  
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Responsable ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El Responsable no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_detected THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         2- PROC ABM taula NIVELLESTUDIS                 */
/***********************************************************/
 
-------------------------------------------------------------
--Nom        :   PROC_A_NIVELLESTUDIS
--Descripci :   Alta d'un nou nivell d'estudis
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_NIVELLESTUDIS 
(
  PDESCRIPCIO IN RESPONSABLE.NOM%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
  
Is
param_input Varchar2(300);
codi_error  Integer;
NULL_incorrecte   exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PDESCRIPCIO='|| PDESCRIPCIO;
  PRSP := 'OK';
  INSERT INTO ECOLLADOF.NIVELLESTUDIS(DESCRIPCIO) VALUES (PDESCRIPCIO);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: La descripci del nivell d estudis no pot ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE); 
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_NIVELLESTUDIS
--Descripci :   Baixa d'un nivell d'estudis
-------------------------------------------------------------
create or replace PROCEDURE  PROC_B_NIVELLESTUDIS 
(PIDESTUDIS IN NIVELLESTUDIS.IDESTUDIS%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
num_reg2         Integer;
donat_de_baixa   exception;
no_existeix      exception;
candidat_associat    exception;
proces_associat    exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDESTUDIS=' || PIDESTUDIS;
   PRSP := 'OK';
   -- Es comprova si exsiteix el nvell d'estudis
   SELECT count(IDESTUDIS) INTO num_reg FROM NIVELLESTUDIS WHERE IDESTUDIS = PIDESTUDIS;
   IF num_reg <> 0 THEN
   	-- Es comprova si t candidats o processos de selecci associats(que no estiguin donats de baixa)
    SELECT count (FIDESTUDIS) INTO num_reg FROM CANDIDAT WHERE FIDESTUDIS = PIDESTUDIS AND DATABAIXA IS NULL;
    SELECT count (FIDESTUDIS) INTO num_reg2 FROM PROCESSELECCIO WHERE FIDESTUDIS = PIDESTUDIS AND DATABAIXA IS NULL;
    IF (num_reg = 0 AND num_reg2 = 0) THEN
      -- Es dna de baixa si no ha estat donat de baixa abans
        UPDATE ECOLLADOF.NIVELLESTUDIS SET DATABAIXA=SYSDATE WHERE IDESTUDIS = PIDESTUDIS AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;
    ELSE
        IF num_reg = 0 THEN 
          raise proces_associat; 
        ELSE
          raise candidat_associat;
        END IF;
    END IF;
  ELSE
      raise no_existeix;
  END IF;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Nivell d estudis ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El Nivell d estudis no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN candidat_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El Nivell d estudis no es pot donar de baixa perqu t Candidats associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN proces_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El Nivell d estudis no es pot donar de baixa perqu t processos de selecci en marxa associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_NIVELLESTUDIS
--Descripci :   Modificaci d'un nivell d'estudis
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_NIVELLESTUDIS 
(
  PIDESTUDIS IN NIVELLESTUDIS.IDESTUDIS%TYPE 
, PDESCRIPCIO IN NIVELLESTUDIS.DESCRIPCIO%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
NULL_detected   exception;

PRAGMA EXCEPTION_INIT(NULL_detected, -1407);

Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PIDESTUDIS='|| PIDESTUDIS ||' PDESCRIPCIO='|| PDESCRIPCIO;
  PRSP := 'OK';
-- Es comprova si existeix el nivell d'estudis
  SELECT count(IDESTUDIS) INTO num_reg FROM NIVELLESTUDIS WHERE IDESTUDIS = PIDESTUDIS;
  IF num_reg <> 0 THEN
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.NIVELLESTUDIS SET DESCRIPCIO = PDESCRIPCIO WHERE IDESTUDIS = PIDESTUDIS  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Nivell d estudis ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El nivell d estudis no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_detected THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         3- PROC ABM taula COMPETENCIAPROFESSIONAL       */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_COMPETENCIAPROFESSIONAL
--Descripci :   Alta d'una competncia professional
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_COMPETENCIAPROFESSIONAL 
(
  PDESCRIPCIO IN COMPETENCIAPROFESSIONAL.DESCRIPCIO%TYPE 
, PDATACREACIO IN COMPETENCIAPROFESSIONAL.DATACREACIO%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
NULL_incorrecte   exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PDESCRIPCIO='|| PDESCRIPCIO || 'PDATACREACIO='|| PDATACREACIO;
  PRSP := 'OK';
  INSERT INTO ECOLLADOF.COMPETENCIAPROFESSIONAL(DESCRIPCIO, DATACREACIO) VALUES (PDESCRIPCIO, PDATACREACIO);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Ni la descripci ni la data de creaci poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_COMPETENCIAPROFESSIONAL
--Descripci :   Baixa d'una competncia professional
-------------------------------------------------------------
create or replace PROCEDURE  PROC_B_COMPETENCIAPROFESSIONAL 
(
  PIDCOMPETENCIA IN COMPETENCIAPROFESSIONAL.IDCOMPETENCIA%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
num_reg2         Integer;
donat_de_baixa   exception;
no_existeix      exception;
candidat_associat    exception;
proces_associat    exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDCOMPETENCIA=' || PIDCOMPETENCIA;
   PRSP := 'OK';
   -- Es comprova si existeix la competencia
   SELECT count(IDCOMPETENCIA) INTO num_reg FROM COMPETENCIAPROFESSIONAL WHERE IDCOMPETENCIA = PIDCOMPETENCIA;
   IF num_reg <> 0 THEN
   	-- Es comprova si t candidats o processos de selecci associats(que no estiguin donats de baixa)
    SELECT count (FIDCOMPETENCIA) INTO num_reg FROM CANDIDATCOMPETENCIA WHERE FIDCOMPETENCIA = PIDCOMPETENCIA AND DATABAIXA IS NULL;
    SELECT count (FIDCOMPETENCIA) INTO num_reg2 FROM PROCESSELCOMPETENCIA WHERE FIDCOMPETENCIA = PIDCOMPETENCIA AND DATABAIXA IS NULL;
    IF (num_reg = 0 AND num_reg2 = 0) THEN
      -- Es dna de baixa si no ha estat donat de baixa abans
        UPDATE ECOLLADOF.COMPETENCIAPROFESSIONAL SET DATABAIXA=SYSDATE WHERE IDCOMPETENCIA = PIDCOMPETENCIA AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;
    ELSE
        IF num_reg = 0 THEN
          raise proces_associat;
        ELSE
          raise candidat_associat;
        END IF;
    END IF;
  ELSE
      raise no_existeix;
  END IF;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Competncia professional ja donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La competncia professional no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN candidat_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La competncia professional no es pot donar de baixa perqu t candidats associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN proces_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La competncia professional no es pot donar de baixa perqu t processos de selecci en marxa associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/


-------------------------------------------------------------
--Nom        :   PROC_M_COMPETENCIAPROFESSIONAL
--Descripci :   Modificaci d'una competncia professional
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_COMPETENCIAPROFESSIONAL 
(
  PIDCOMPETENCIA IN COMPETENCIAPROFESSIONAL.IDCOMPETENCIA%TYPE 
, PDESCRIPCIO IN COMPETENCIAPROFESSIONAL.DESCRIPCIO%TYPE 
, PDATACREACIO IN COMPETENCIAPROFESSIONAL.DATACREACIO%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
NULL_detected   exception;

PRAGMA EXCEPTION_INIT(NULL_detected, -1407);

Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PIDCOMPETENCIA='|| PIDCOMPETENCIA ||' PDESCRIPCIO='|| PDESCRIPCIO ||' PDATACREACIO='|| PDATACREACIO;
  PRSP := 'OK';
-- Es comprova si existeix nivell d'estudis
  SELECT count(IDCOMPETENCIA) INTO num_reg FROM COMPETENCIAPROFESSIONAL WHERE IDCOMPETENCIA = PIDCOMPETENCIA;
  IF num_reg <> 0 THEN
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.COMPETENCIAPROFESSIONAL SET DESCRIPCIO = PDESCRIPCIO, DATACREACIO = PDATACREACIO WHERE IDCOMPETENCIA = PIDCOMPETENCIA  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Competncia professional ja donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La competncia professional no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_detected THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         4- PROC ABM taula SEU                           */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_SEU
--Descripci :   Alta d'una nova Seu
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_SEU 
(
  PFIDRESPONSABLE IN SEU.FIDRESPONSABLE%TYPE 
, PPOBLACIO IN SEU.POBLACIO%TYPE 
, PCODIPOSTAL IN SEU.CODIPOSTAL%TYPE
, PADRECA IN SEU.ADRECA%TYPE 
, PDATAINAUGURACIO IN SEU.DATAINAUGURACIO%TYPE
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
no_responsable  exception;
NULL_incorrecte   exception;
error_integritat  exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
PRAGMA EXCEPTION_INIT(error_integritat, -2291);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDRESPONSABLE='|| PFIDRESPONSABLE ||'PPOBLACIO='|| PPOBLACIO ||'PCODIPOSTA='|| PCODIPOSTAL ||'PADRECA='|| PADRECA || 'PDATAINAUGURACIO='|| PDATAINAUGURACIO;
  PRSP := 'OK';
  --comprovem si existeix el responsable i no est donat de baixa
  SELECT count(IDRESPONSABLE) INTO num_reg FROM RESPONSABLE WHERE IDRESPONSABLE = PFIDRESPONSABLE AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_responsable; END IF;
  --Alta de la nova seu
  INSERT INTO ECOLLADOF.SEU(FIDRESPONSABLE, POBLACIO, CODIPOSTAL, ADRECA, DATAINAUGURACIO) 
    VALUES (PFIDRESPONSABLE, PPOBLACIO, PCODIPOSTAL, PADRECA, PDATAINAUGURACIO);
  codi_error := SQLCODE;
  --Registre a la taula LOG
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Ni el codi del responsable ni la data inauguracio poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_responsable THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El codi del responsable no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_SEU
--Descripci :   Baixa d'una seu
-------------------------------------------------------------
create or replace PROCEDURE  PROC_B_SEU 
(
  PIDSEU IN SEU.IDSEU%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
num_cli         Integer;
num_com         Integer;
num_cand        Integer;
num_ent         Integer;
donat_de_baixa   exception;
no_existeix      exception;
candidat_associat    exception;
client_associat    exception;
comercial_associat exception;
entrevistai_associada exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDSEU=' || PIDSEU;
   PRSP := 'OK';
   -- Es comprova si existeix la seu
   SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PIDSEU;
   
   IF num_reg <> 0 THEN
      -- Es comprova si t registres associats(que no estiguin donats de baixa)
      SELECT count (FIDSEU) INTO num_cli FROM CLIENT WHERE FIDSEU = PIDSEU AND DATABAIXA IS NULL;
      IF num_cli <> 0 THEN raise client_associat; END IF; 
      SELECT count (FIDSEU) INTO num_com FROM COMERCIAL WHERE FIDSEU = PIDSEU AND DATABAIXA IS NULL;
      IF num_com <> 0 THEN raise comercial_associat; END IF;
      SELECT count (FIDSEU) INTO num_cand FROM CANDIDAT WHERE FIDSEU = PIDSEU AND DATABAIXA IS NULL;
      IF num_cand <> 0 THEN raise candidat_associat;END IF;
      SELECT count (FIDSEU) INTO num_ent FROM ENTREVISTAINTERNA WHERE FIDSEU = PIDSEU AND DATABAIXA IS NULL;
      IF num_ent <> 0 THEN raise entrevistai_associada; END IF;
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.SEU SET DATABAIXA=SYSDATE WHERE IDSEU = PIDSEU AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Seu ja donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La seu no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN candidat_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La seu no es pot donar de baixa perqu t candidats associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN client_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La seu no es pot donar de baixa perqu t clients associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
    WHEN comercial_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La seu no es pot donar de baixa perqu t comercials associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
    WHEN entrevistai_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La seu no es pot donar de baixa perqu t entrevistes internes associades';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_SEU
--Descripci :   Modificai d'una seu
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_SEU 
(
  PIDSEU IN SEU.IDSEU%TYPE 
, PFIDRESPONSABLE IN SEU.FIDRESPONSABLE%TYPE 
, PPOBLACIO IN SEU.POBLACIO%TYPE 
, PCODIPOSTAL IN SEU.CODIPOSTAL%TYPE 
, PADRECA IN SEU.ADRECA%TYPE 
, PDATAINAUGURACIO IN SEU.DATAINAUGURACIO%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
no_responsable  exception;
NULL_detected   exception;

PRAGMA EXCEPTION_INIT(NULL_detected, -1407);

Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PIDSEU=' || PIDSEU ||'PFIDRESPONSABLE='|| PFIDRESPONSABLE ||'PPOBLACIO='|| PPOBLACIO ||'PCODIPOSTA='|| PCODIPOSTAL ||'PADRECA='|| PADRECA || 'PDATAINAUGURACIO='|| PDATAINAUGURACIO;
  PRSP := 'OK';
-- Es comprova si existeix la seu
  SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PIDSEU;
  IF num_reg <> 0 THEN
  -- comprovem si el codi del responsable existeix
    SELECT count(IDRESPONSABLE) INTO num_reg FROM RESPONSABLE WHERE IDRESPONSABLE = PFIDRESPONSABLE AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_responsable; END IF;
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.SEU SET FIDRESPONSABLE = PFIDRESPONSABLE, POBLACIO = PPOBLACIO, CODIPOSTAL=PCODIPOSTAL, ADRECA=PADRECA, DATAINAUGURACIO=PDATAINAUGURACIO WHERE IDSEU = PIDSEU  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Seu ja donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La seu no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_detected THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
    
  WHEN no_responsable THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: El responsable de la seu no existeix o b est donat de baixa' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         5- PROC ABM taula COMERCIAL                     */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_COMERCIAL
--Descripci :   Alta d'un nou comercial
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_COMERCIAL 
(
  PFIDSEU IN COMERCIAL.FIDSEU%TYPE 
, PNOM IN COMERCIAL.NOM%TYPE 
, PADRECA IN COMERCIAL.ADRECA%TYPE 
, PPOBLACIO IN COMERCIAL.POBLACIO%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
no_seu  exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDSEU='|| PFIDSEU ||'PNOM='|| PNOM ||'PADRECA='|| PADRECA ||'PPOBLACIO='|| PPOBLACIO;
  PRSP := 'OK';
  --comprovem si la seu existeix i no est donada de baixa
  SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PFIDSEU AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_seu; END IF;
  -- Alta del comercial
  INSERT INTO ECOLLADOF.COMERCIAL(FIDSEU, NOM, ADRECA, POBLACIO) 
    VALUES (PFIDSEU, PNOM, PADRECA, PPOBLACIO);
  codi_error := SQLCODE;
  -- Registrem a la taula LOG
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Ni el codi de la seu ni el nom del comercial poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_seu THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El codi de la seu associada no existeix o b est donada de baixa' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_COMERCIAL
--Descripci :   Baixa d'un comercial
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_B_COMERCIAL 
(
  PIDCOMERCIAL IN COMERCIAL.IDCOMERCIAL%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
num_cli         Integer;
num_vis         Integer;
num_pro        Integer;
donat_de_baixa   exception;
no_existeix      exception;
visita_associada    exception;
client_associat    exception;
proposta_associada exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDCOMERCIAL=' || PIDCOMERCIAL;
   PRSP := 'OK';
   -- Es comprova si existeix el comercial
   SELECT count(IDCOMERCIAL) INTO num_reg FROM COMERCIAL WHERE IDCOMERCIAL = PIDCOMERCIAL;
   
   IF num_reg <> 0 THEN
      -- Es comprova si t registres associats(que no estiguin donats de baixa)
      SELECT count (FIDCOMERCIAL) INTO num_cli FROM CLIENT WHERE FIDCOMERCIAL = PIDCOMERCIAL AND DATABAIXA IS NULL;
      IF num_cli <> 0 THEN raise client_associat; END IF; 
      SELECT count (FIDCOMERCIAL) INTO num_vis FROM VISITACOMERCIAL WHERE FIDCOMERCIAL = PIDCOMERCIAL AND DATABAIXA IS NULL;
      IF num_vis <> 0 THEN raise visita_associada; END IF; 
      SELECT count (FIDCOMERCIAL) INTO num_pro FROM PROPOSTACOMERCIAL WHERE FIDCOMERCIAL = PIDCOMERCIAL AND DATABAIXA IS NULL;
      IF num_pro <> 0 THEN raise proposta_associada; END IF; 
      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.COMERCIAL SET DATABAIXA=SYSDATE WHERE IDCOMERCIAL = PIDCOMERCIAL AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Comercial ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El comercial no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN client_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El comercial no es pot donar de baixa perqu t clients associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN visita_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El comercial no es pot donar de baixa perqu t visites comercials associades';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN proposta_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El comnercial no es pot donar de baixa perqu t propostes comercials associades'; 
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_COMERCIAL
--Descripci :   Modificaci d'un comercial
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_COMERCIAL 
(
  PIDCOMERCIAL IN COMERCIAL.IDCOMERCIAL%TYPE 
, PFIDSEU IN COMERCIAL.FIDSEU%TYPE
, PNOM IN COMERCIAL.NOM%TYPE 
, PADRECA IN COMERCIAL.ADRECA%TYPE 
, PPOBLACIO IN COMERCIAL.POBLACIO%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
no_seu  exception;
NULL_detected   exception;

PRAGMA EXCEPTION_INIT(NULL_detected, -1407);

Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PIDCOMERCIAL='|| PIDCOMERCIAL ||'PFIDSEU='|| PFIDSEU ||'PNOM='|| PNOM ||'PADRECA='|| PADRECA ||'PPOBLACIO='|| PPOBLACIO;
  PRSP := 'OK';
-- Es comprova si existeix el comercial
  SELECT count(IDCOMERCIAL) INTO num_reg FROM COMERCIAL WHERE IDCOMERCIAL = PIDCOMERCIAL;
  IF num_reg <> 0 THEN
  -- comprovem si el codi  de la seu existeix
    SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PFIDSEU AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_seu; END IF;
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.COMERCIAL SET FIDSEU = PFIDSEU, NOM = PNOM, ADRECA=PADRECA, POBLACIO=PPOBLACIO WHERE IDCOMERCIAL = PIDCOMERCIAL  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Comercial ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El comercial no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_detected THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
    
  WHEN no_seu THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: La seu que es vol associar al comercial no existeix o b est donada de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         6- PROC ABM taula CLIENT                        */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_CLIENT
--Descripci :   Alta d'un nou comercial
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_CLIENT 
(
  PFIDSEU IN CLIENT.FIDSEU%TYPE 
, PFIDCOMERCIAL IN CLIENT.FIDCOMERCIAL%TYPE
, PNOM IN CLIENT.NOM%TYPE 
, PADRECA IN CLIENT.ADRECA%TYPE 
, PPOBLACIO IN CLIENT.POBLACIO%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
no_seu  exception;
no_comercial exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
   -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDSEU='|| PFIDSEU ||'PFIDCOMERCIAL='|| PFIDCOMERCIAL ||'PNOM='|| PNOM ||'PADRECA='|| PADRECA ||'PPOBLACIO='|| PPOBLACIO;
  PRSP := 'OK';
  --comprovem si la seu existeix i no est donada de baixa
  SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PFIDSEU AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_seu; END IF;
  --comprovem si el comercial existeix i no est donat de baixa
  SELECT count(IDCOMERCIAL) INTO num_reg FROM COMERCIAL WHERE IDCOMERCIAL = PFIDCOMERCIAL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_comercial; END IF;
  -- Alta client
  INSERT INTO ECOLLADOF.CLIENT(FIDSEU, FIDCOMERCIAL, NOM, ADRECA, POBLACIO) 
    VALUES (PFIDSEU, PFIDCOMERCIAL, PNOM, PADRECA, PPOBLACIO);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Ni el codi de la seu ni el del comercial ni el nom del client poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_seu THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: La seu associada no exiteix o b est donada de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_comercial THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El comercial associat no exiteix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/


-------------------------------------------------------------
--Nom        :   PROC_B_CLIENT
--Descripci :   Baixa d'un comercial
-------------------------------------------------------------
create or replace PROCEDURE  PROC_B_CLIENT 
(
  PIDCLIENT IN CLIENT.IDCLIENT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
num_proc         Integer;
num_vis         Integer;
num_prop        Integer;
num_ent         Integer;
donat_de_baixa   exception;
no_existeix      exception;
visita_associada    exception;
proces_associat    exception;
proposta_associada exception;
entrevista_associada exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDCLIENT=' || PIDCLIENT;
   PRSP := 'OK';
   -- Es comprova si existeix el client
   SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PIDCLIENT;
   IF num_reg <> 0 THEN
      -- Es comprova si t registres associats(que no estiguin donats de baixa)
      SELECT count (FIDCLIENT) INTO num_proc FROM PROCESSELECCIO WHERE FIDCLIENT = PIDCLIENT AND DATABAIXA IS NULL;
      IF num_proc <> 0 THEN raise proces_associat; END IF; 
      SELECT count (FIDCLIENT) INTO num_vis FROM VISITACOMERCIAL WHERE FIDCLIENT = PIDCLIENT AND DATABAIXA IS NULL;
      IF num_vis <> 0 THEN raise visita_associada; END IF; 
      SELECT count (FIDCLIENT) INTO num_prop FROM PROPOSTACOMERCIAL WHERE FIDCLIENT = PIDCLIENT AND DATABAIXA IS NULL;
      IF num_prop <> 0 THEN raise proposta_associada; END IF; 
      SELECT count (FIDCLIENT) INTO num_ent FROM ENTREVISTAEXTERNA WHERE FIDCLIENT = PIDCLIENT AND DATABAIXA IS NULL;
      IF num_ent <> 0 THEN raise entrevista_associada; END IF; 
      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.CLIENT SET DATABAIXA=SYSDATE WHERE IDCLIENT = PIDCLIENT AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Client ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El client no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN entrevista_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El client no es pot donar de baixa perqu t entrevistes associades';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN visita_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El client no es pot donar de baixa perqu t visites comercials associades';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN proposta_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El client no es pot donar de baixa perqu t propostes comercials associades'; 
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
    WHEN proces_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El client no es pot donar de baixa perqu t processos de selecci associats'; 
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/


-------------------------------------------------------------
--Nom        :   PROC_M_CLIENT
--Descripci :   Modificaci d'un comercial
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_CLIENT 
(
  PIDCLIENT IN CLIENT.IDCLIENT%TYPE
, PFIDSEU IN CLIENT.FIDSEU%TYPE 
, PFIDCOMERCIAL IN CLIENT.FIDCOMERCIAL%TYPE
, PNOM IN CLIENT.NOM%TYPE 
, PADRECA IN CLIENT.ADRECA%TYPE 
, PPOBLACIO IN CLIENT.POBLACIO%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
no_seu  exception;
no_comercial  exception;
NULL_detected   exception;

PRAGMA EXCEPTION_INIT(NULL_detected, -1407);

Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PIDCLIENT='|| PIDCLIENT ||'PFIDSEU='|| PFIDSEU ||'PFIDCOMERCIAL='|| PFIDCOMERCIAL ||'PNOM='|| PNOM ||'PADRECA='|| PADRECA ||'PPOBLACIO='|| PPOBLACIO;
  PRSP := 'OK';
-- Es comprova si existeix el client
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PIDCLIENT;
  IF num_reg <> 0 THEN
  -- comprovem si el codi  de la seu existeix
    SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PFIDSEU AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_seu; END IF;
    -- comprovem si el codi  del comercial existeix
    SELECT count(IDCOMERCIAL) INTO num_reg FROM COMERCIAL WHERE IDCOMERCIAL = PFIDCOMERCIAL AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_comercial; END IF;
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.CLIENT SET FIDSEU = PFIDSEU, FIDCOMERCIAL =PFIDCOMERCIAL, NOM = PNOM, ADRECA=PADRECA, POBLACIO=PPOBLACIO WHERE IDCLIENT = PIDCLIENT  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Client ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El client no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_detected THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
    
  WHEN no_seu THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: La seu que es vol associar al client no existeix  o b est donada de baixa' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_comercial THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: El comercial que es vol associar al client no existeix o b est donat de baixa' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         7- PROC ABM taula PROCESCAPTACIO                */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_PROCESCAPTACIO
--Descripci :   Alta d'un nou procs de captaci
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_PROCESCAPTACIO 
(
  PTIPUS IN PROCESCAPTACIO.TIPUS%TYPE 
, PDATAINICI IN PROCESCAPTACIO.DATAINICI%TYPE
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PTIPUS='|| PTIPUS ||'PDATAINICI='|| PDATAINICI;
  PRSP := 'OK';
  INSERT INTO ECOLLADOF.PROCESCAPTACIO(TIPUS, DATAINICI) 
    VALUES (PTIPUS, PDATAINICI);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Ni el tipus ni la data d inici poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_PROCESCAPTACIO
--Descripci :   Baixa d'un procs de captaci
-------------------------------------------------------------
create or replace PROCEDURE  PROC_B_PROCESCAPTACIO 
(
  PIDPROCESCAP IN PROCESCAPTACIO.IDPROCESCAP%TYPE
, PRSP OUT NOCOPY VARCHAR2
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
num_cand         Integer;
donat_de_baixa   exception;
no_existeix      exception;
candidat_associat    exception;
Begin
   -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDPROCESCAP=' || PIDPROCESCAP;
   PRSP := 'OK';
   -- Es comprova si existeix el procs de captaci
   SELECT count(IDPROCESCAP) INTO num_reg FROM PROCESCAPTACIO WHERE IDPROCESCAP = PIDPROCESCAP;
   IF num_reg <> 0 THEN
      -- Es comprova si t candidats associats(que no estiguin donats de baixa)
      SELECT count (FIDPROCESCAP) INTO num_cand FROM CANDIDAT WHERE FIDPROCESCAP = PIDPROCESCAP AND DATABAIXA IS NULL;
      IF num_cand <> 0 THEN raise candidat_associat; END IF; 
      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.PROCESCAPTACIO SET DATABAIXA=SYSDATE WHERE IDPROCESCAP = PIDPROCESCAP AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Procs de captaci ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El procs de captaci no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN candidat_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El procs de captaci no es pot donar de baixa perqu t candidats associats';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_PROCESCAPTACIO
--Descripci :   Modificaci d'un procs de captaci
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_PROCESCAPTACIO 
(
  PIDPROCESCAP IN PROCESCAPTACIO.IDPROCESCAP%TYPE
, PTIPUS IN PROCESCAPTACIO.TIPUS%TYPE 
, PDATAINICI IN PROCESCAPTACIO.DATAINICI%TYPE
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
NULL_incorrecte   exception;

PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1407);

Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PIDPROCESCAP=' ||PIDPROCESCAP || 'PTIPUS='|| PTIPUS ||'PDATAINICI='|| PDATAINICI;
  PRSP := 'OK';
-- Es comprova si existeix el procs de captaci
  SELECT count(IDPROCESCAP) INTO num_reg FROM PROCESCAPTACIO WHERE IDPROCESCAP = PIDPROCESCAP;
  IF num_reg <> 0 THEN
  -- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.PROCESCAPTACIO SET TIPUS=PTIPUS, DATAINICI=PDATAINICI WHERE IDPROCESCAP = PIDPROCESCAP  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Procs de captaci ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El procs de captaci no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
    
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         8- PROC ABM taula CANDIDAT                      */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_CANDIDAT
--Descripci :   Alta d'un nou candidat
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_CANDIDAT 
(
  PFIDSEU IN CANDIDAT.FIDSEU%TYPE 
, PFIDPROCESCAP IN CANDIDAT.FIDPROCESCAP%TYPE 
, PFIDESTUDIS IN CANDIDAT.FIDESTUDIS%TYPE 
, PNOM IN CANDIDAT.NOM%TYPE 
, PDATANAIXEMENT IN CANDIDAT.DATANAIXEMENT%TYPE 
, PMOBILITAT IN CANDIDAT.MOBILITAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_check  exception;
no_seu  exception;
no_procescap exception;
no_estudis exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDSEU='|| PFIDSEU ||'PFIDPROCESCAP='|| PFIDPROCESCAP ||'PFIDESTUDIS='|| PFIDESTUDIS ||'PNOM='|| PNOM 
  ||'PDATANAIXEMENT='|| PDATANAIXEMENT ||'PMOBILITAT='|| PMOBILITAT;
  PRSP := 'OK';
  --comprovem si la seu existeix i no est donada de baixa
  SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PFIDSEU AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_seu; END IF;
  --comprovem si el proces de captaci existeix i no est donat de baixa
  SELECT count(IDPROCESCAP) INTO num_reg FROM PROCESCAPTACIO WHERE IDPROCESCAP = PFIDPROCESCAP AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_procescap; END IF;
  --comprovem si el nivell d'estudis existeix i no est donat de baixa
  SELECT count(IDESTUDIS) INTO num_reg FROM NIVELLESTUDIS WHERE IDESTUDIS = PFIDESTUDIS AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_estudis; END IF;
  INSERT INTO ECOLLADOF.CANDIDAT(FIDSEU, FIDPROCESCAP, FIDESTUDIS, NOM,DATANAIXEMENT, MOBILITAT) 
    VALUES (PFIDSEU, PFIDPROCESCAP, PFIDESTUDIS, PNOM, PDATANAIXEMENT, PMOBILITAT);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
 WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp mobilitat (S/N) o selclient (S/N) ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_seu THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: La seu associada no exiteix o b est donada de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_procescap THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El procs de captaci no exiteix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_estudis THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El nivell d estudis no exiteix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_CANDIDAT
--Descripci :   Baixa d'un candidat
-------------------------------------------------------------
create or replace PROCEDURE  PROC_B_CANDIDAT 
(
  PIDCANDIDAT IN CANDIDAT.IDCANDIDAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
num_candcomp         Integer;
num_candproc         Integer;
num_ente         Integer;
num_enti         Integer;
donat_de_baixa   exception;
no_existeix      exception;
competencia_associada    exception;
proces_associat    exception;
entrevistae_associada exception;
entrevistai_associada exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDCANDIDAT=' || PIDCANDIDAT;
   PRSP := 'OK';
   -- Es comprova si existeix el candidat
   SELECT count(IDCANDIDAT) INTO num_reg FROM CANDIDAT WHERE IDCANDIDAT = PIDCANDIDAT;
   IF num_reg <> 0 THEN
      -- Es comprova si t registres associats(que no estiguin donats de baixa)
      SELECT count (FIDCANDIDAT) INTO num_candcomp FROM CANDIDATCOMPETENCIA WHERE FIDCANDIDAT = PIDCANDIDAT AND DATABAIXA IS NULL;
      IF num_candcomp <> 0 THEN raise competencia_associada; END IF; 
      SELECT count (FIDCANDIDAT) INTO num_candproc FROM CANDIDATPROCESSEL WHERE FIDCANDIDAT = PIDCANDIDAT AND DATABAIXA IS NULL;
      IF num_candproc <> 0 THEN raise proces_associat; END IF; 
      SELECT count (FIDCANDIDAT) INTO num_ente FROM ENTREVISTAEXTERNA WHERE FIDCANDIDAT = PIDCANDIDAT AND DATABAIXA IS NULL;
      IF num_ente <> 0 THEN raise entrevistae_associada; END IF; 
      SELECT count (FIDCANDIDAT) INTO num_enti FROM ENTREVISTAINTERNA WHERE FIDCANDIDAT = PIDCANDIDAT AND DATABAIXA IS NULL;
      IF num_enti <> 0 THEN raise entrevistai_associada; END IF; 
      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.CANDIDAT SET DATABAIXA=SYSDATE WHERE IDCANDIDAT = PIDCANDIDAT AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Candidat ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El candidat no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN entrevistae_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El candidat no es pot donar de baixa perqu t entrevistes externes associades';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN entrevistai_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El candidat no es pot donar de baixa perqu t entrevistes internes associades';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN proces_associat THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El candidat no es pot donar de baixa perqu t processos de selecci associats'; 
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN competencia_associada THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El candidat no es pot donar de baixa perqu t competncies associats'; 
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_CANDIDAT
--Descripci :   Modificaci d'un candidat
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_CANDIDAT 
(
  PIDCANDIDAT IN CANDIDAT.IDCANDIDAT%TYPE
, PFIDSEU IN CANDIDAT.FIDSEU%TYPE 
, PFIDPROCESCAP IN CANDIDAT.FIDPROCESCAP%TYPE 
, PFIDESTUDIS IN CANDIDAT.FIDESTUDIS%TYPE 
, PNOM IN CANDIDAT.NOM%TYPE 
, PDATANAIXEMENT IN CANDIDAT.DATANAIXEMENT%TYPE 
, PMOBILITAT IN CANDIDAT.MOBILITAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
no_seu  exception;
no_procescap  exception;
no_estudis    exception;
NULL_incorrecte   exception;

PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1407);

Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PIDCANDIDAT=' || PIDCANDIDAT || 'PFIDSEU='|| PFIDSEU ||'PFIDPROCESCAP='|| PFIDPROCESCAP ||'PFIDESTUDIS='|| PFIDESTUDIS ||'PNOM='|| PNOM 
  ||'PDATANAIXEMENT='|| PDATANAIXEMENT ||'PMOBILITAT='|| PMOBILITAT;
  PRSP := 'OK';
-- Es comprova si existeix el candidat
  SELECT count(IDCANDIDAT) INTO num_reg FROM CANDIDAT WHERE IDCANDIDAT = PIDCANDIDAT;
  IF num_reg <> 0 THEN
  -- comprovem si el codi  de la seu existeix
    SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PFIDSEU AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_seu; END IF;
    -- comprovem si el codi  del proces de captaci existeic i no est donat de baixa
    SELECT count(IDPROCESCAP) INTO num_reg FROM PROCESCAPTACIO WHERE IDPROCESCAP = PFIDPROCESCAP AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_procescap; END IF;
    -- comprovem si el codi  del nivell d'estudis existeix i no est donat de baixa
    SELECT count(IDESTUDIS) INTO num_reg FROM NIVELLESTUDIS WHERE IDESTUDIS = PFIDESTUDIS AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_estudis; END IF;
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.CANDIDAT SET FIDSEU = PFIDSEU, FIDPROCESCAP =PFIDPROCESCAP, FIDESTUDIS=PFIDESTUDIS, NOM = PNOM, DATANAIXEMENT=PDATANAIXEMENT, 
     MOBILITAT=PMOBILITAT WHERE IDCANDIDAT = PIDCANDIDAT  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Candidat ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El candidat no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
    
  WHEN no_seu THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: La seu que es vol associar al candidat no existeix  o b est donada de baixa' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_procescap THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: El proces de captaci que es vol associar al candidat no existeix o b est donat de baixa' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
 WHEN no_estudis THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: El nivell d estudis que es vol associar al candidat no existeix o b est donat de baixa' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/


/***********************************************************/
/*         9- PROC ABM taula ENTREVISTAINTERNA             */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_ENTREVISTAINTERNA
--Descripci :   Alta d'una entrevista interna
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_ENTREVISTAINTERNA 
(
  PFIDSEU IN ENTREVISTAINTERNA.FIDSEU%TYPE 
, PFIDCANDIDAT IN ENTREVISTAINTERNA.FIDCANDIDAT%TYPE
, PDATA IN ENTREVISTAINTERNA.DATA%TYPE 
, PRESULTAT IN ENTREVISTAINTERNA.RESULTAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
error_check  exception;
no_seu  exception;
no_candidat exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDSEU='|| PFIDSEU ||'PFIDCANDIDAT='|| PFIDCANDIDAT ||'PDATA='|| PDATA ||'PRESULTAT='|| PRESULTAT;
  PRSP := 'OK';
  --comprovem si la seu existeix i no est donada de baixa
  SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PFIDSEU AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_seu; END IF;
  --comprovem si el candidat existeix i no est donat de baixa
  SELECT count(IDCANDIDAT) INTO num_reg FROM CANDIDAT WHERE IDCANDIDAT = PFIDCANDIDAT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_candidat; END IF;
  INSERT INTO ECOLLADOF.ENTREVISTAINTERNA(FIDSEU, FIDCANDIDAT, DATA, RESULTAT) 
    VALUES (PFIDSEU, PFIDCANDIDAT, PDATA, PRESULTAT);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions  
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp resultat (P/N)' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_seu THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: La seu associada no exiteix o b est donada de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_candidat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El candidat associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_ENTREVISTAINTERNA
--Descripci :   Baixa d'una entrevista interna
-------------------------------------------------------------
create or replace PROCEDURE  PROC_B_ENTREVISTAINTERNA
(
  PIDENTREVISTAI IN ENTREVISTAINTERNA.IDENTREVISTAI%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDENTREVISTAI=' || PIDENTREVISTAI;
   PRSP := 'OK';
   -- Es comprova si existeix la entrevista interna
   SELECT count(IDENTREVISTAI) INTO num_reg FROM ENTREVISTAINTERNA WHERE IDENTREVISTAI = PIDENTREVISTAI;
   IF num_reg <> 0 THEN      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.ENTREVISTAINTERNA SET DATABAIXA=SYSDATE WHERE IDENTREVISTAI = PIDENTREVISTAI AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Entrevista interna ja donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Lentrevista interna no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_ENTREVISTAINTERNA
--Descripci :   Modificaci d'una entrevista interna
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_ENTREVISTAINTERNA 
(
  PIDENTREVISTAI IN ENTREVISTAINTERNA.IDENTREVISTAI%TYPE
, PFIDSEU IN ENTREVISTAINTERNA.FIDSEU%TYPE 
, PFIDCANDIDAT IN ENTREVISTAINTERNA.FIDCANDIDAT%TYPE
, PDATA IN ENTREVISTAINTERNA.DATA%TYPE 
, PRESULTAT IN ENTREVISTAINTERNA.RESULTAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
no_seu  exception;
no_candidat  exception;
error_check  exception;
NULL_detected   exception;

PRAGMA EXCEPTION_INIT(NULL_detected, -1407);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
-- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
param_input := 'PIDENTREVISTAI=' || PIDENTREVISTAI || 'PFIDSEU='|| PFIDSEU ||'PFIDCANDIDAT='|| PFIDCANDIDAT ||'PDATA='|| PDATA ||'PRESULTAT='|| PRESULTAT;
  PRSP := 'OK';
-- Es comprova si existeix lentrevista interna
  SELECT count(IDENTREVISTAI) INTO num_reg FROM ENTREVISTAINTERNA WHERE IDENTREVISTAI = PIDENTREVISTAI;
  IF num_reg <> 0 THEN
  -- comprovem si el codi  de la seu existeix
    SELECT count(IDSEU) INTO num_reg FROM SEU WHERE IDSEU = PFIDSEU AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_seu; END IF;
    -- comprovem si el codi  del candidat existeix
    SELECT count(IDCANDIDAT) INTO num_reg FROM CANDIDAT WHERE IDCANDIDAT = PFIDCANDIDAT AND DATABAIXA IS NULL;
    IF num_reg =0 THEN raise no_candidat; END IF;
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.ENTREVISTAINTERNA SET FIDSEU = PFIDSEU, FIDCANDIDAT =PFIDCANDIDAT, DATA = PDATA, RESULTAT=PRESULTAT WHERE IDENTREVISTAI = PIDENTREVISTAI  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La entrevista interna ja est donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: L entrevista interna no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_detected THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp resultat (P/N)' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;    
  WHEN no_seu THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: La seu associada no exiteix o b est donada de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_candidat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El candidat associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/


/***********************************************************/
/*         10- PROC ABM taula PROCESSELECCIO               */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_PROCESSELECCIO               
--Descripci :   Alta d'un nou procs de selecci
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_PROCESSELECCIO
(
  PFIDCLIENT IN PROCESSELECCIO.FIDCLIENT%TYPE 
, PFIDESTUDIS IN PROCESSELECCIO.FIDESTUDIS%TYPE
, PDATAINICI IN PROCESSELECCIO.DATAINICI%TYPE 
, PDATAFI IN PROCESSELECCIO.DATAFI%TYPE 
, PRESULTAT IN PROCESSELECCIO.RESULTAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
error_check  exception;
no_client  exception;
no_estudis exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDCLIENT='|| PFIDCLIENT ||'PFIDESTUDIS='|| PFIDESTUDIS ||'PDATAINICI='|| PDATAINICI || 'PDATAFI='|| PDATAFI ||'PRESULTAT='|| PRESULTAT;
  PRSP := 'OK';
  --comprovem si el client existeix i no est donat de baixa
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PFIDCLIENT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_client; END IF;
  --comprovem si el nivell destudis existeix i no est donat de baixa
  SELECT count(IDESTUDIS) INTO num_reg FROM NIVELLESTUDIS WHERE IDESTUDIS = PFIDESTUDIS AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_estudis; END IF;
  INSERT INTO ECOLLADOF.PROCESSELECCIO (FIDCLIENT, FIDESTUDIS, DATAINICI, DATAFI, RESULTAT) 
    VALUES (PFIDCLIENT, PFIDESTUDIS, PDATAINICI, PDATAFI, PRESULTAT);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp resultat (P/N)' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_client THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El client associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_estudis THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El nivell d estudis associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_PROCESSELECCIO               
--Descripci :   Modificaci d'un procs de selecci
-------------------------------------------------------------
create or replace PROCEDURE  PROC_B_PROCESSELECCIO
(
  PIDPROCESSEL IN PROCESSELECCIO.IDPROCESSEL%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDPROCESSEL=' || PIDPROCESSEL;
   PRSP := 'OK';
   -- Es comprova si existeix el procs de selecci
   SELECT count(IDPROCESSEL) INTO num_reg FROM PROCESSELECCIO WHERE IDPROCESSEL = PIDPROCESSEL;
   IF num_reg <> 0 THEN      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.PROCESSELECCIO SET DATABAIXA=SYSDATE WHERE IDPROCESSEL = PIDPROCESSEL AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Procs de selecci ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El procs de selecci no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_PROCESSELECCIO               
--Descripci :   Baixa d'un procs de selecci
-------------------------------------------------------------
create or replace PROCEDURE  PROC_M_PROCESSELECCIO 
(
  PIDPROCESSEL IN PROCESSELECCIO.IDPROCESSEL%TYPE
, PFIDCLIENT IN PROCESSELECCIO.FIDCLIENT%TYPE 
, PFIDESTUDIS IN PROCESSELECCIO.FIDESTUDIS%TYPE
, PDATAINICI IN PROCESSELECCIO.DATAINICI%TYPE 
, PDATAFI IN PROCESSELECCIO.DATAFI%TYPE 
, PRESULTAT IN PROCESSELECCIO.RESULTAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
no_client  exception;
no_estudis  exception;
error_check  exception;
NULL_incorrecte   exception;

PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1407);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
-- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
param_input := 'PIDPROCESSEL=' || PIDPROCESSEL ||' PFIDCLIENT='|| PFIDCLIENT ||' PFIDESTUDIS='|| PFIDESTUDIS ||' PDATAINICI='|| PDATAINICI || ' PDATAFI='|| PDATAFI ||' PRESULTAT='|| PRESULTAT;
  PRSP := 'OK';
-- Es comprova si existeix el procs de selecci
  SELECT count(IDPROCESSEL) INTO num_reg FROM PROCESSELECCIO WHERE IDPROCESSEL = PIDPROCESSEL;
  IF num_reg <> 0 THEN
  --comprovem si el client existeix i no est donat de baixa
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PFIDCLIENT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_client; END IF;
  --comprovem si el nivell destudis existeix i no est donat de baixa
  SELECT count(IDESTUDIS) INTO num_reg FROM NIVELLESTUDIS WHERE IDESTUDIS = PFIDESTUDIS AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_estudis; END IF;
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.PROCESSELECCIO SET FIDCLIENT = PFIDCLIENT, FIDESTUDIS =PFIDESTUDIS, DATAINICI = PDATAINICI, DATAFI= PDATAFI, RESULTAT=PRESULTAT WHERE IDPROCESSEL = PIDPROCESSEL AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Procs de selecci ja donat de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: El procs de selecci no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp resultat (P/N)' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;    
  WHEN no_client THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El client associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_estudis THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El nivell d estudis associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         11- PROC ABM taula ENTREVISTAEXTERNA            */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_ ENTREVISTAEXTERNA            
--Descripci :   Alta d'una entrevista externa
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE PROC_A_ENTREVISTAEXTERNA 
(
  PFIDCLIENT IN ENTREVISTAEXTERNA .FIDCLIENT%TYPE 
, PFIDCANDIDAT IN ENTREVISTAEXTERNA .FIDCANDIDAT%TYPE 
, PFIDPROCESSEL IN ENTREVISTAEXTERNA .FIDPROCESSEL%TYPE 
, PDATA IN ENTREVISTAEXTERNA.DATA%TYPE 
, PRESULTAT IN ENTREVISTAEXTERNA .RESULTAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
error_check  exception;
no_client  exception;
no_candidat exception;
no_processel  exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDCLIENT='|| PFIDCLIENT ||'PFIDCANDIDAT='|| PFIDCANDIDAT ||'PFIDPROCESSEL='|| PFIDPROCESSEL || 'PDATA='|| PDATA ||'PRESULTAT='|| PRESULTAT;
  PRSP := 'OK';
  --comprovem si el client existeix i no est donat de baixa
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PFIDCLIENT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_client; END IF;
  --comprovem si el candidat existeix i no est donat de baixa
  SELECT count(IDCANDIDAT) INTO num_reg FROM CANDIDAT WHERE IDCANDIDAT = PFIDCANDIDAT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_candidat; END IF;
   --comprovem si el procs de selecci existeix i no est donat de baixa
  SELECT count(IDPROCESSEL) INTO num_reg FROM PROCESSELECCIO WHERE IDPROCESSEL = PFIDPROCESSEL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_processel; END IF;
  INSERT INTO ENTREVISTAEXTERNA(FIDCLIENT, FIDCANDIDAT, FIDPROCESSEL, DATA, RESULTAT) 
    VALUES (PFIDCLIENT, PFIDCANDIDAT, PFIDPROCESSEL, PDATA, PRESULTAT);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp resultat (P/N/R)' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_client THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El client no exiteix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_candidat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El candidat associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_processel THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El procs de selecci associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
   WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_ ENTREVISTAEXTERNA            
--Descripci :   Baixa d'una entrevista externa
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_B_ENTREVISTAEXTERNA 
(
  PIDENTREVISTAE IN ENTREVISTAEXTERNA.IDENTREVISTAE%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDENTREVISTAE=' || PIDENTREVISTAE;
   PRSP := 'OK';
   -- Es comprova si existeix la entrevista externa
   SELECT count(IDENTREVISTAE) INTO num_reg FROM ENTREVISTAEXTERNA WHERE IDENTREVISTAE = PIDENTREVISTAE;
   IF num_reg <> 0 THEN      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.ENTREVISTAEXTERNA SET DATABAIXA=SYSDATE WHERE IDENTREVISTAE = PIDENTREVISTAE AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Entrevista externa ja donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Lentrevista externa no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/


-------------------------------------------------------------
--Nom        :   PROC_M_ ENTREVISTAEXTERNA            
--Descripci :   Modificaci d'una entrevista externa 
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_M_ENTREVISTAEXTERNA 
(
  PIDENTREVISTAE IN ENTREVISTAINTERNA.IDENTREVISTAI%TYPE
, PFIDCLIENT IN ENTREVISTAEXTERNA .FIDCLIENT%TYPE 
, PFIDCANDIDAT IN ENTREVISTAEXTERNA .FIDCANDIDAT%TYPE 
, PFIDPROCESSEL IN ENTREVISTAEXTERNA .FIDPROCESSEL%TYPE 
, PDATA IN ENTREVISTAEXTERNA.DATA%TYPE 
, PRESULTAT IN ENTREVISTAEXTERNA .RESULTAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
no_client  exception;
no_candidat  exception;
no_processel  exception;
error_check  exception;
NULL_incorrecte   exception;

PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1407);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
-- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
param_input := 'PIDENTREVISTAE=' || PIDENTREVISTAE || 'PFIDCLIENT='|| PFIDCLIENT ||'PFIDCANDIDAT='|| PFIDCANDIDAT ||'PFIDPROCESSEL='|| PFIDPROCESSEL || 'PDATA='|| PDATA ||'PRESULTAT='|| PRESULTAT;
  PRSP := 'OK';
-- Es comprova si existeix lentrevista externa
  SELECT count(IDENTREVISTAE) INTO num_reg FROM ENTREVISTAEXTERNA WHERE IDENTREVISTAE = PIDENTREVISTAE;
  IF num_reg <> 0 THEN
  --comprovem si el client existeix i no est donat de baixa
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PFIDCLIENT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_client; END IF;
  --comprovem si el candidat existeix i no est donat de baixa
  SELECT count(IDCANDIDAT) INTO num_reg FROM CANDIDAT WHERE IDCANDIDAT = PFIDCANDIDAT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_candidat; END IF;
   --comprovem si el procs de selecci existeix i no est donat de baixa
  SELECT count(IDPROCESSEL) INTO num_reg FROM PROCESSELECCIO WHERE IDPROCESSEL = PFIDPROCESSEL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_processel; END IF;
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.ENTREVISTAEXTERNA SET FIDCLIENT = PFIDCLIENT, FIDCANDIDAT =PFIDCANDIDAT, FIDPROCESSEL=PFIDPROCESSEL, DATA = PDATA, RESULTAT=PRESULTAT WHERE IDENTREVISTAE = PIDENTREVISTAE  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La entrevista externa ja est donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La entrevista externa no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp resultat (P/N/R)' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;    
 WHEN no_client THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El client no exiteix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_candidat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El candidat associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_processel THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El procs de selecci associat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/


/***********************************************************/
/*         12- PROC ABM taula VISITACOMERCIAL              */
/***********************************************************/
-------------------------------------------------------------
--Nom        :   PROC_A_VISITACOMERCIAL              
--Descripci :   Alta d'una visita comercial
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE PROC_A_VISITACOMERCIAL 
(
  PFIDCOMERCIAL IN VISITACOMERCIAL.FIDCOMERCIAL%TYPE 
, PFIDCLIENT IN VISITACOMERCIAL.FIDCLIENT%TYPE 
, PDATAVISITA IN VISITACOMERCIAL.DATAVISITA%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
no_comercial  exception;
no_client  exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDCOMERCIAL='|| PFIDCOMERCIAL ||' PFIDCLIENT='|| PFIDCLIENT || ' PDATAVISITA='|| PDATAVISITA;
  PRSP := 'OK';
  --comprovem si el comerciaL existeix i no est donat de baixa
  SELECT count(IDCOMERCIAL) INTO num_reg FROM COMERCIAL WHERE IDCOMERCIAL = PFIDCOMERCIAL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_comercial; END IF;
  --comprovem si el client existeix i no est donat de baixa
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PFIDCLIENT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_client; END IF;
  INSERT INTO VISITACOMERCIAL(FIDCOMERCIAL, FIDCLIENT, DATAVISITA) 
    VALUES (PFIDCOMERCIAL, PFIDCLIENT, PDATAVISITA);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_comercial THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El comercial no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_client THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El client no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_VISITACOMERCIAL              
--Descripci :   Baixa d'una visita comercial
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_B_VISITACOMERCIAL 
(
  PIDVISITA IN VISITACOMERCIAL.IDVISITA%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDVISITA=' || PIDVISITA;
   PRSP := 'OK';
   -- Es comprova si existeix la visita comercial
   SELECT count(IDVISITA) INTO num_reg FROM VISITACOMERCIAL WHERE IDVISITA = PIDVISITA;
   IF num_reg <> 0 THEN      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.VISITACOMERCIAL SET DATABAIXA=SYSDATE WHERE IDVISITA = PIDVISITA AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Visita comercial ja donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La visita comercial no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_VISITACOMERCIAL              
--Descripci :   Modificaci d'una visita comercial
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_M_VISITACOMERCIAL 
(
  PIDVISITA IN VISITACOMERCIAL.IDVISITA%TYPE
, PFIDCOMERCIAL IN VISITACOMERCIAL.FIDCOMERCIAL%TYPE 
, PFIDCLIENT IN VISITACOMERCIAL.FIDCLIENT%TYPE 
, PDATAVISITA IN VISITACOMERCIAL.DATAVISITA%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_comercial	exception;
no_existeix     exception;
no_client  exception;
NULL_incorrecte   exception;

PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1407);
Begin
-- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
param_input := 'PIDVISITA=' || PIDVISITA ||' PFIDCOMERCIAL='|| PFIDCOMERCIAL ||' PFIDCLIENT='|| PFIDCLIENT || ' PDATAVISITA='|| PDATAVISITA;
  PRSP := 'OK';
-- Es comprova si existeix la visita comercial
  SELECT count(IDVISITA) INTO num_reg FROM VISITACOMERCIAL WHERE IDVISITA = PIDVISITA;
  IF num_reg <> 0 THEN  
  --comprovem si el comercial existeix i no est donat de baixa
  SELECT count(IDCOMERCIAL) INTO num_reg FROM COMERCIAL WHERE IDCOMERCIAL = PFIDCOMERCIAL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_comercial; END IF;
 --comprovem si el client existeix i no est donat de baixa
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PFIDCLIENT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_client; END IF; 
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.VISITACOMERCIAL SET FIDCOMERCIAL=PFIDCOMERCIAL, FIDCLIENT = PFIDCLIENT, DATAVISITA = PDATAVISITA WHERE IDVISITA = PIDVISITA  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La visita comercial est donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La visita comercial no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_comercial THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El comercial no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_client THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El client no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
 WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         13- PROC ABM taula PROPOSTACOMERCIAL            */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_PROPOSTACOMERCIAL
--Descripci :   Alta d'una proposta comercial
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE PROC_A_PROPOSTACOMERCIAL 
(
  PFIDCOMERCIAL IN PROPOSTACOMERCIAL.FIDCOMERCIAL%TYPE 
, PFIDCLIENT IN PROPOSTACOMERCIAL.FIDCLIENT%TYPE 
, PIMPORT IN PROPOSTACOMERCIAL.IMPORT%TYPE 
, PDATAPROPOSTA IN PROPOSTACOMERCIAL.DATAPROPOSTA%TYPE 
, PESTAT IN PROPOSTACOMERCIAL.ESTAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
error_check  exception;
no_comercial  exception;
no_client exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDCOMERCIAL=' || PFIDCOMERCIAL || ' PFIDCLIENT='|| PFIDCLIENT ||' PIMPORT='|| PIMPORT || ' PDATAPROPOSTA='|| PDATAPROPOSTA ||' PESTAT='|| PESTAT;
  PRSP := 'OK';
  --comprovem si el comercial existeix i no est donat de baixa
  SELECT count(IDCOMERCIAL) INTO num_reg FROM COMERCIAL WHERE IDCOMERCIAL = PFIDCOMERCIAL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_comercial; END IF;
--comprovem si el client existeix i no est donat de baixa
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PFIDCLIENT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_client; END IF;

  INSERT INTO PROPOSTACOMERCIAL(FIDCOMERCIAL, FIDCLIENT, IMPORT,  DATAPROPOSTA, ESTAT) 
    VALUES (PFIDCOMERCIAL, PFIDCLIENT, PIMPORT,  PDATAPROPOSTA, PESTAT);
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp estat (A/R)' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_comercial THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El comercial no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
 WHEN no_client THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El client no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_PROPOSTACOMERCIAL
--Descripci :   Baixa d'una proposta comercial
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_B_PROPOSTACOMERCIAL 
(
  PIDPROPOSTA IN PROPOSTACOMERCIAL.IDPROPOSTA%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PIDPROPOSTA=' || PIDPROPOSTA;
   PRSP := 'OK';
   -- Es comprova si existeix la proposta comercial
   SELECT count(IDPROPOSTA) INTO num_reg FROM PROPOSTACOMERCIAL WHERE IDPROPOSTA = PIDPROPOSTA;
   IF num_reg <> 0 THEN      
      -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.PROPOSTACOMERCIAL SET DATABAIXA=SYSDATE WHERE IDPROPOSTA = PIDPROPOSTA AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: Proposta comercial ja donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La proposta comercial no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_M_PROPOSTACOMERCIAL
--Descripci :   Modificaci d'una proposta comercial
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_M_PROPOSTACOMERCIAL 
(
  PIDPROPOSTA IN PROPOSTACOMERCIAL.IDPROPOSTA%TYPE 
, PFIDCOMERCIAL IN PROPOSTACOMERCIAL.FIDCOMERCIAL%TYPE 
, PFIDCLIENT IN PROPOSTACOMERCIAL.FIDCLIENT%TYPE 
, PIMPORT IN PROPOSTACOMERCIAL.IMPORT%TYPE 
, PDATAPROPOSTA IN PROPOSTACOMERCIAL.DATAPROPOSTA%TYPE 
, PESTAT IN PROPOSTACOMERCIAL.ESTAT%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input     Varchar2(300);
codi_error      Integer;
num_reg         Integer;
donat_de_baixa  exception;
no_existeix     exception;
no_comercial	Exception;
no_client  exception;
error_check  exception;
NULL_incorrecte   exception;

PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1407);
PRAGMA EXCEPTION_INIT(error_check, -2290);
Begin
-- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
param_input := 'PIDPROPOSTA=' || PIDPROPOSTA || ' PFIDCOMERCIAL=' || PFIDCOMERCIAL || ' PFIDCLIENT='|| PFIDCLIENT ||' PIMPORT='|| PIMPORT || ' PDATAPROPOSTA='|| PDATAPROPOSTA ||' PESTAT='|| PESTAT;
  PRSP := 'OK';
-- Es comprova si existeix la proposta comercial
  SELECT count(IDPROPOSTA) INTO num_reg FROM PROPOSTACOMERCIAL WHERE IDPROPOSTA = PIDPROPOSTA;
  IF num_reg <> 0 THEN
  --comprovem si el comercial existeix i no est donat de baixa
  SELECT count(IDCOMERCIAL) INTO num_reg FROM COMERCIAL WHERE IDCOMERCIAL = PFIDCOMERCIAL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_comercial; END IF;
--comprovem si el client existeix i no est donat de baixa
  SELECT count(IDCLIENT) INTO num_reg FROM CLIENT WHERE IDCLIENT = PFIDCLIENT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_client; END IF;
-- Si existeix i no est de baixa es fa l'actualitzaci
	   UPDATE ECOLLADOF.PROPOSTACOMERCIAL SET FIDCOMERCIAL=PFIDCOMERCIAL, FIDCLIENT = PFIDCLIENT, IMPORT=PIMPORT, DATAPROPOSTA = PDATAPROPOSTA, ESTAT=PESTAT WHERE IDPROPOSTA = PIDPROPOSTA  AND DATABAIXA IS NULL;
	   codi_error := SQLCODE;
     IF (SQL%ROWCOUNT = 0) THEN
        raise donat_de_baixa;
     END IF;
  ELSE
	   raise no_existeix;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
     VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La proposta comercial ja est donada de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La proposta comercial no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: Es vol modificar a NULL un camp que no ho permet ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN error_check THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Valors incorrectes en el camp estat (A/R)' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;    
 WHEN no_comercial THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El comercial no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_client THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El client no exiteix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;

  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         14- PROC ABM taula CANDIDATCOMPETENCIA          */
/***********************************************************/
-------------------------------------------------------------
--Nom        :   PROC_A_CANDIDATCOMPETENCIA
--Descripci :   Alta d'una competncia dun candidat
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_CANDIDATCOMPETENCIA 
(
  PFIDCANDIDAT IN CANDIDATCOMPETENCIA.FIDCANDIDAT%TYPE 
, PFIDCOMPETENCIA IN CANDIDATCOMPETENCIA.FIDCOMPETENCIA%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
no_candidat  exception;
no_competencia  exception;
ja_assignat	exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDCANDIDAT='|| PFIDCANDIDAT ||' PFIDCOMPETENCIA='|| PFIDCOMPETENCIA;
  PRSP := 'OK';
  --comprovem si el candidat existeix i no est donat de baixa
  SELECT count(IDCANDIDAT) INTO num_reg FROM CANDIDAT WHERE IDCANDIDAT = PFIDCANDIDAT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_candidat; END IF;
  --comprovem si competncia professional existeix i no est donada de baixa
  SELECT count(IDCOMPETENCIA) INTO num_reg FROM COMPETENCIAPROFESSIONAL WHERE IDCOMPETENCIA = PFIDCOMPETENCIA AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_competencia; END IF;
--comprovem si la competncia ja est assignada al candidat
  SELECT count(FIDCANDIDAT) INTO num_reg FROM CANDIDATCOMPETENCIA WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDCOMPETENCIA = PFIDCOMPETENCIA AND DATABAIXA IS NULL;
  IF num_reg<>0 THEN RAISE ja_assignat; END IF;
  -- comprovem si la competncia havia estat donada de baixa anteriorment, en aquest cas eliminem la data de baixa
  SELECT count(FIDCANDIDAT) INTO num_reg FROM CANDIDATCOMPETENCIA WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDCOMPETENCIA = PFIDCOMPETENCIA AND DATABAIXA IS NOT NULL;
  IF num_reg<>0 THEN
    UPDATE CANDIDATCOMPETENCIA SET DATABAIXA=NULL WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDCOMPETENCIA = PFIDCOMPETENCIA;
  ELSE
  INSERT INTO CANDIDATCOMPETENCIA(FIDCANDIDAT, FIDCOMPETENCIA) 
    VALUES (PFIDCANDIDAT, PFIDCOMPETENCIA);
  END IF;
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_candidat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El candidat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_competencia THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: La competencia no existeix o b est donada de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ja_assignat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Aquesta competencia professional ja es troba assignada a aquest candidat' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;

  WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_CANDIDATCOMPETENCIA
--Descripci :   Baixa d'una competncia dun candidat
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_B_CANDIDATCOMPETENCIA 
(
  PFIDCANDIDAT IN CANDIDATCOMPETENCIA.FIDCANDIDAT%TYPE 
, PFIDCOMPETENCIA IN CANDIDATCOMPETENCIA.FIDCOMPETENCIA%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PFIDCANDIDAT='|| PFIDCANDIDAT ||' PFIDCOMPETENCIA='|| PFIDCOMPETENCIA;
   PRSP := 'OK';
   --comprovem si existeix la competncia assignada al candidat
  SELECT count(FIDCANDIDAT) INTO num_reg FROM CANDIDATCOMPETENCIA WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDCOMPETENCIA = PFIDCOMPETENCIA;
  IF num_reg<>0 THEN
 -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.CANDIDATCOMPETENCIA SET DATABAIXA=SYSDATE WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDCOMPETENCIA=PFIDCOMPETENCIA AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La relaci candidat-competncia ja es troba donada  de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La relaci candidat-competncia no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         15- PROC ABM taula CANDIDATPROCESSEL            */
/***********************************************************/
-------------------------------------------------------------
--Nom        :   PROC_A_CANDIDATPROCESSEL
--Descripci :   Alta d'un candidat en un procs de selecci
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_CANDIDATPROCESSEL 
(
  PFIDCANDIDAT IN CANDIDATPROCESSEL.FIDCANDIDAT%TYPE 
, PFIDPROCESSEL IN CANDIDATPROCESSEL.FIDPROCESSEL%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
no_candidat  exception;
no_processel exception;
ja_assignat	exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDCANDIDAT='|| PFIDCANDIDAT ||' PFIDPROCESSEL='|| PFIDPROCESSEL;
  PRSP := 'OK';
  --comprovem si el candidat existeix i no est donat de baixa
  SELECT count(IDCANDIDAT) INTO num_reg FROM CANDIDAT WHERE IDCANDIDAT = PFIDCANDIDAT AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_candidat; END IF;
  --comprovem si el procs de selecci existeix i no est donat de baixa
  SELECT count(IDPROCESSEL) INTO num_reg FROM PROCESSELECCIO WHERE IDPROCESSEL = PFIDPROCESSEL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_processel; END IF;
--comprovem si el candidat ja est assignat al procs de selecci
  SELECT count(FIDCANDIDAT) INTO num_reg FROM CANDIDATPROCESSEL WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDPROCESSEL = PFIDPROCESSEL AND DATABAIXA IS NULL;
  IF num_reg<>0 THEN RAISE ja_assignat; END IF;
  -- comprovem si el candidat havia estat donat de baixa anteriorment, en aquest cas eliminem la data de baixa
  SELECT count(FIDCANDIDAT) INTO num_reg FROM CANDIDATPROCESSEL WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDPROCESSEL = PFIDPROCESSEL AND DATABAIXA IS NOT NULL;
  IF num_reg<>0 THEN
    UPDATE CANDIDATPROCESSEL SET DATABAIXA=NULL WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDPROCESSEL = PFIDPROCESSEL;
  ELSE
  INSERT INTO CANDIDATPROCESSEL(FIDCANDIDAT, FIDPROCESSEL) 
    VALUES (PFIDCANDIDAT, PFIDPROCESSEL);
  codi_error := SQLCODE;
  END IF;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_candidat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El candidat no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_processel THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El procs de selecci no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ja_assignat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Aquest candidat ja es troba assignat a aquest procs de selecci' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;

  WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_CANDIDATPROCESSEL
--Descripci :   Baixa d'un candidat en un procs de selecci
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_B_CANDIDATPROCESSEL 
(
  PFIDCANDIDAT IN CANDIDATPROCESSEL.FIDCANDIDAT%TYPE 
, PFIDPROCESSEL IN CANDIDATPROCESSEL.FIDPROCESSEL%TYPE 
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PFIDCANDIDAT='|| PFIDCANDIDAT ||' PFIDPROCESSEL='|| PFIDPROCESSEL;
   PRSP := 'OK';
   --comprovem si existeix el candidat assignat al procs de selecci
  SELECT count(FIDCANDIDAT) INTO num_reg FROM CANDIDATPROCESSEL WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDPROCESSEL = PFIDPROCESSEL;
  IF num_reg<>0 THEN
 -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.CANDIDATPROCESSEL SET DATABAIXA=SYSDATE WHERE FIDCANDIDAT = PFIDCANDIDAT AND FIDPROCESSEL=PFIDPROCESSEL AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La relaci candidat-procs de selecci ja es troba donada  de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La relaci candidat-procs de selecci no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

/***********************************************************/
/*         16- PROC ABM taula PROCESSELCOMPETENCIA         */
/***********************************************************/

-------------------------------------------------------------
--Nom        :   PROC_A_PROCESSELCOMPETENCIA
--Descripci :   Alta d'una competncia en un procs selecci
-------------------------------------------------------------
create or replace PROCEDURE PROC_A_PROCESSELCOMPETENCIA 
(
  PFIDPROCESSEL IN PROCESSELCOMPETENCIA.FIDPROCESSEL%TYPE 
, PFIDCOMPETENCIA IN PROCESSELCOMPETENCIA.FIDCOMPETENCIA%TYPE
, PRSP OUT NOCOPY VARCHAR2 
)

Is
param_input Varchar2(300);
codi_error  Integer;
num_reg Integer;
NULL_incorrecte   exception;
error_integritat  exception;
no_competencia  exception;
no_processel exception;
ja_assignat	exception;
PRAGMA EXCEPTION_INIT(NULL_incorrecte, -1400);
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
  param_input := 'PFIDPROCESSEL='|| PFIDPROCESSEL ||' PFIDCOMPETENCIA='|| PFIDCOMPETENCIA;
  PRSP := 'OK';
  --comprovem si el procs de selecci existeix i no est donat de baixa
  SELECT count(IDPROCESSEL) INTO num_reg FROM PROCESSELECCIO WHERE IDPROCESSEL = PFIDPROCESSEL AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_processel; END IF;
  --comprovem si la competncia existeix i no est donada de baixa
  SELECT count(IDCOMPETENCIA) INTO num_reg FROM COMPETENCIAPROFESSIONAL WHERE IDCOMPETENCIA = PFIDCOMPETENCIA AND DATABAIXA IS NULL;
  IF num_reg=0 THEN RAISE no_competencia; END IF;
--comprovem si la competncia ja est assignada al procs de selecci
  SELECT count(FIDPROCESSEL) INTO num_reg FROM PROCESSELCOMPETENCIA WHERE FIDPROCESSEL = PFIDPROCESSEL AND FIDCOMPETENCIA = PFIDCOMPETENCIA AND DATABAIXA IS NULL;
  IF num_reg<>0 THEN RAISE ja_assignat; END IF;
  -- comprovem si la competncia havia estat donada de baixa anteriorment, en aquest cas eliminem la data de baixa
  SELECT count(FIDPROCESSEL) INTO num_reg FROM PROCESSELCOMPETENCIA WHERE FIDPROCESSEL = PFIDPROCESSEL AND FIDCOMPETENCIA = PFIDCOMPETENCIA AND DATABAIXA IS NOT NULL;
  IF num_reg<>0 THEN
    UPDATE PROCESSELCOMPETENCIA SET DATABAIXA=NULL WHERE FIDPROCESSEL = PFIDPROCESSEL AND FIDCOMPETENCIA = PFIDCOMPETENCIA;
  ELSE
  INSERT INTO PROCESSELCOMPETENCIA(FIDPROCESSEL, FIDCOMPETENCIA) 
    VALUES (PFIDPROCESSEL, PFIDCOMPETENCIA);
  END IF;
  codi_error := SQLCODE;
  INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
    VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  Dbms_output.Put_line(PRSP);
  Commit;
-- tractament de les excepcions
Exception
  WHEN NULL_incorrecte THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Hi ha camps que no poden ser NULL ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_competencia THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: La competncia professional no existeix o b est donada de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_processel THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: El procs de selecci no existeix o b est donat de baixa ' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ja_assignat THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: Aquesta competncia ja es troba assignada a aquest procs de selecci' || codi_error ||' ' || SQLERRM ,1,100);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN DUP_VAL_ON_INDEX THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= SUBSTR('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/

-------------------------------------------------------------
--Nom        :   PROC_B_PROCESSELCOMPETENCIA
--Descripci :   Baixa d'una competncia en un procs selecci
-------------------------------------------------------------
CREATE OR REPLACE PROCEDURE  PROC_B_PROCESSELCOMPETENCIA 
(
  PFIDPROCESSEL IN PROCESSELCOMPETENCIA.FIDPROCESSEL%TYPE 
, PFIDCOMPETENCIA IN PROCESSELCOMPETENCIA.FIDCOMPETENCIA%TYPE
, PRSP OUT NOCOPY VARCHAR2 
)
Is
param_input      Varchar2(300);
codi_error       Integer;
num_reg          Integer;
donat_de_baixa   exception;
no_existeix      exception;
Begin
  -- Guardem els parmetres d'entrada per desprs poder inserir-los a la taula LOG
   param_input := 'PFIDPROCESSEL='|| PFIDPROCESSEL ||' PFIDCOMPETENCIA='|| PFIDCOMPETENCIA;
   PRSP := 'OK';
--comprovem si la competncia ja est assignada al procs de selecci
  SELECT count(FIDPROCESSEL) INTO num_reg FROM PROCESSELCOMPETENCIA WHERE FIDPROCESSEL = PFIDPROCESSEL AND FIDCOMPETENCIA = PFIDCOMPETENCIA;
  IF num_reg<>0 THEN
 -- Es dna de baixa si no ha estat donat de baixa abans
      UPDATE ECOLLADOF.PROCESSELCOMPETENCIA SET DATABAIXA=SYSDATE WHERE FIDPROCESSEL = PFIDPROCESSEL AND FIDCOMPETENCIA=PFIDCOMPETENCIA AND DATABAIXA IS NULL;
        codi_error := SQLCODE;
        IF (SQL%ROWCOUNT = 0) THEN
          raise donat_de_baixa;
        END IF;  
    ELSE
      raise no_existeix;
    END IF;
      
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
   Dbms_output.Put_line(PRSP);
   Commit;
-- tractament de les excepcions
Exception
  WHEN donat_de_baixa THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La relaci competncia-procs de selecci ja es troba donada  de baixa';
    Dbms_output.Put_line(PRSP);
    Rollback;
   INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN no_existeix THEN
    codi_error := SQLCODE;
    PRSP:= 'ERROR: La relaci competncia-procs de selecci no existeix';
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN ROWTYPE_MISMATCH THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
  WHEN Others THEN
    codi_error := SQLCODE;
    PRSP:= Substr('ERROR: ' || codi_error ||' ' || SQLERRM ,1,50);
    Dbms_output.Put_line(PRSP);
    Rollback;
    INSERT INTO ECOLLADOF.LOG(NOMPROCEDIMENT, PARAMENTRADA, RSP, DATAEXECUCIO)
      VALUES($$PLSQL_UNIT, SUBSTR(param_input,1,300), PRSP, SYSDATE);
    Commit;
End;
/




